@@ -181,7 +181,7 @@ def matlab_compatible(name):
     return compatible_name[:60]
 
 
-def get_text_v3(address, stream, mapped=False):
+def get_text_v3(address, stream, mapped=False, decode=True):
     """ faster way to extract strings from mdf versions 2 and 3 TextBlock
 
     Parameters
@@ -199,25 +199,28 @@ def get_text_v3(address, stream, mapped=False):
     """
 
     if address == 0:
-        return ""
+        return "" if decode else b""
 
     if mapped:
-        size, = UINT16_uf(stream, address + 2)
-        text_bytes = stream[address + 4: address + size]
+        (size,) = UINT16_uf(stream, address + 2)
+        text_bytes = stream[address + 4 : address + size].strip(b" \r\t\n\0")
     else:
         stream.seek(address + 2)
         size = UINT16_u(stream.read(2))[0] - 4
-        text_bytes = stream.read(size)
-    try:
-        text = text_bytes.strip(b" \r\t\n\0").decode("latin-1")
-    except UnicodeDecodeError:
-        encoding = detect(text_bytes)["encoding"]
-        text = text_bytes.strip(b" \r\t\n\0").decode(encoding, 'ignore')
+        text_bytes = stream.read(size).strip(b" \r\t\n\0")
+    if decode:
+        try:
+            text = text_bytes.decode("latin-1")
+        except UnicodeDecodeError:
+            encoding = detect(text_bytes)["encoding"]
+            text = text_bytes.decode(encoding, "ignore")
+    else:
+        text = text_bytes
 
     return text
 
 
-def get_text_v4(address, stream, mapped=False):
+def get_text_v4(address, stream, mapped=False, decode=True):
     """ faster way to extract strings from mdf version 4 TextBlock
 
     Parameters
@@ -235,20 +238,23 @@ def get_text_v4(address, stream, mapped=False):
     """
 
     if address == 0:
-        return ""
+        return "" if decode else b""
 
     if mapped:
-        size, = UINT64_uf(stream, address + 8)
-        text_bytes = stream[address + 24: address + size]
+        (size,) = UINT64_uf(stream, address + 8)
+        text_bytes = stream[address + 24 : address + size].strip(b" \r\t\n\0")
     else:
         stream.seek(address + 8)
         size, _ = TWO_UINT64_u(stream.read(16))
-        text_bytes = stream.read(size - 24)
-    try:
-        text = text_bytes.strip(b" \r\t\n\0").decode("utf-8")
-    except UnicodeDecodeError:
-        encoding = detect(text_bytes)["encoding"]
-        text = text_bytes.strip(b" \r\t\n\0").decode(encoding, 'ignore')
+        text_bytes = stream.read(size - 24).strip(b" \r\t\n\0")
+    if decode:
+        try:
+            text = text_bytes.decode("utf-8")
+        except UnicodeDecodeError:
+            encoding = detect(text_bytes)["encoding"]
+            text = text_bytes.decode(encoding, "ignore")
+    else:
+        text = text_bytes
 
     return text
 
@@ -574,8 +580,10 @@ def as_non_byte_sized_signed_int(integer_array, bit_length):
             (1 << bit_length) - 1
         )  # Zero out the unwanted bits
     return where(
-        truncated_integers >> bit_length - 1,  # sign bit as a truth series (True when negative)
-        (2 ** bit_length - truncated_integers) * -1,  # when negative, do two's complement
+        truncated_integers
+        >> bit_length - 1,  # sign bit as a truth series (True when negative)
+        (2 ** bit_length - truncated_integers)
+        * -1,  # when negative, do two's complement
         truncated_integers,  # when positive, return the truncated int
     )
 
@@ -614,7 +622,7 @@ def debug_channel(mdf, group, channel, dependency, file=None):
 
     cg = group["channel_group"]
     print("CHANNEL GROUP", "=" * 66, file=file)
-    print(cg, file=file)
+    print(cg, cg.cycles_nr, cg.samples_byte_nr, cg.invalidation_bytes_nr, file=file)
     print(file=file)
 
     print("CHANNEL", "=" * 72, file=file)
@@ -740,7 +748,6 @@ def validate_version_argument(version, hint=4):
 
 
 class ChannelsDB(dict):
-
     def __init__(self, version=4):
         super().__init__()
 
@@ -758,17 +765,17 @@ class ChannelsDB(dict):
         """
         if channel_name:
             if channel_name not in self:
-                self[channel_name] = [entry]
+                self[channel_name] = (entry,)
             else:
-                self[channel_name].append(entry)
+                self[channel_name] += (entry,)
 
             if "\\" in channel_name:
-                channel_name = channel_name.split("\\")[0]
+                channel_name, _ = channel_name.split("\\", 1)
 
                 if channel_name not in self:
-                    self[channel_name] = [entry]
+                    self[channel_name] = (entry,)
                 else:
-                    self[channel_name].append(entry)
+                    self[channel_name] += (entry,)
 
 
 def randomized_string(size):
@@ -958,6 +965,10 @@ class Group:
         "signal_types",
         "trigger",
         "string_dtypes",
+        "single_channel_dtype",
+        "uses_ld",
+        "ignore_during_save",
+        "read_split_count",
     )
 
     def __init__(self, data_group):
@@ -981,6 +992,10 @@ class Group:
         self.trigger = None
         self.string_dtypes = None
         self.data_blocks = []
+        self.single_channel_dtype = None
+        self.uses_ld = False
+        self.ignore_during_save = False
+        self.read_split_count = 0
 
     def __getitem__(self, item):
         return self.__getattribute__(item)
@@ -995,6 +1010,27 @@ class Group:
         return hasattr(self, item)
 
 
+class VirtualChannelGroup:
+    """ starting with MDF v4.20 it is possible to use remote masters and column
+    oriented storage. This means we now have virtual channel groups that can
+    span over multiple regular channel groups. This class facilitates the
+    handling of this virtual groups """
+
+    __slots__ = (
+        "groups",
+        "record_size",
+        "cycles_nr",
+    )
+
+    def __init__(self):
+        self.groups = []
+        self.record_size = 0
+        self.cycles_nr = 0
+
+    def __repr__(self):
+        return f'VirtualChannelGroup(groups={self.groups}, records_size={self.record_size}, cycles_nr={self.cycles_nr})'
+
+
 def block_fields(obj):
     fields = []
     for attr in dir(obj):
@@ -1011,13 +1047,8 @@ def block_fields(obj):
 
 
 def components(
-        channel,
-        channel_name,
-        unique_names,
-        prefix="",
-        master=None,
-        only_basenames=False,
-    ):
+    channel, channel_name, unique_names, prefix="", master=None, only_basenames=False,
+):
     """ yield pandas Series and unique name based on the ndarray object
 
     Parameters
@@ -1084,7 +1115,9 @@ def components(
 
             if values.dtype.names:
                 yield from components(
-                    values, name, unique_names,
+                    values,
+                    name,
+                    unique_names,
                     prefix=f"{prefix}.{channel_name}" if prefix else f"{channel_name}",
                     master=master,
                     only_basenames=only_basenames,
@@ -1093,7 +1126,9 @@ def components(
             else:
                 if not only_basenames:
                     name_ = unique_names.get_unique_name(
-                        f"{prefix}.{channel_name}.{name}" if prefix else f"{channel_name}.{name}"
+                        f"{prefix}.{channel_name}.{name}"
+                        if prefix
+                        else f"{channel_name}.{name}"
                     )
                 else:
                     name_ = unique_names.get_unique_name(name)
@@ -1106,22 +1141,32 @@ def components(
 class DataBlockInfo:
 
     __slots__ = (
-        'address',
-        'block_type',
-        'raw_size',
-        'size',
-        'param',
-        'invalidation_block',
+        "address",
+        "block_type",
+        "raw_size",
+        "size",
+        "param",
+        "invalidation_block",
+        "block_limit",
     )
 
-    def __init__(self, address, block_type, raw_size, size, param, invalidation_block=None):
+    def __init__(
+        self,
+        address,
+        block_type,
+        raw_size,
+        size,
+        param,
+        invalidation_block=None,
+        block_limit=None,
+    ):
         self.address = address
         self.block_type = block_type
         self.raw_size = raw_size
         self.size = size
         self.param = param
         self.invalidation_block = invalidation_block
-
+        self.block_limit = block_limit
 
     def __repr__(self):
         return (
@@ -1130,18 +1175,26 @@ class DataBlockInfo:
             f"raw_size={self.raw_size}, "
             f"size={self.size}, "
             f"param={self.param}, "
-            f"invalidation_block={self.invalidation_block})"
+            f"invalidation_block={self.invalidation_block}, "
+            f"block_limit={self.block_limit})"
         )
 
 
 class InvalidationBlockInfo(DataBlockInfo):
 
-    __slots__ = (
-        'all_valid',
-    )
+    __slots__ = ("all_valid",)
 
-    def __init__(self, address, block_type, raw_size, size, param, all_valid=False):
-        super().__init__(address, block_type, raw_size, size, param)
+    def __init__(
+        self,
+        address,
+        block_type,
+        raw_size,
+        size,
+        param,
+        all_valid=False,
+        block_limit=None,
+    ):
+        super().__init__(address, block_type, raw_size, size, param, block_limit)
         self.all_valid = all_valid
 
     def __repr__(self):
@@ -1151,17 +1204,18 @@ class InvalidationBlockInfo(DataBlockInfo):
             f"raw_size={self.raw_size}, "
             f"size={self.size}, "
             f"param={self.param}, "
-            f"all_valid={self.all_valid})"
+            f"all_valid={self.all_valid}, "
+            f"block_limit={self.block_limit})"
         )
 
 
 class SignalDataBlockInfo:
 
     __slots__ = (
-        'address',
-        'size',
-        'count',
-        'offsets',
+        "address",
+        "size",
+        "count",
+        "offsets",
     )
 
     def __init__(self, address, size, count, offsets=None):
@@ -1196,9 +1250,9 @@ def get_fields(obj):
 # code snippet taken from https://www.kaggle.com/arjanso/reducing-dataframe-memory-size-by-65
 def downcast(array):
     kind = array.dtype.kind
-    if kind == 'f':
+    if kind == "f":
         array = array.astype(np.float32)
-    elif kind in 'ui':
+    elif kind in "ui":
         min_ = array.min()
         max_ = array.max()
         if min_ >= 0:
@@ -1242,25 +1296,22 @@ def master_using_raster(mdf, raster, endpoint=False):
 
     """
     if not raster:
-        master = np.array([], dtype='<f8')
+        master = np.array([], dtype="<f8")
     else:
 
         t_min = []
         t_max = []
-        for i, group in enumerate(mdf.groups):
+        for group_index in mdf.virtual_groups:
+            group = mdf.groups[group_index]
             cycles_nr = group.channel_group.cycles_nr
             if cycles_nr:
                 master_min = mdf.get_master(
-                    i,
-                    record_offset=0,
-                    record_count=1,
+                    group_index, record_offset=0, record_count=1,
                 )
                 if len(master_min):
                     t_min.append(master_min[0])
                 master_max = mdf.get_master(
-                    i,
-                    record_offset=cycles_nr-1,
-                    record_count=1,
+                    group_index, record_offset=cycles_nr - 1, record_count=1,
                 )
                 if len(master_max):
                     t_max.append(master_max[0])
@@ -1278,7 +1329,7 @@ def master_using_raster(mdf, raster, endpoint=False):
                     master = np.concatenate([master, [t_max]])
 
         else:
-            master = np.array([], dtype='<f8')
+            master = np.array([], dtype="<f8")
 
     return master
 
@@ -1295,6 +1346,13 @@ def extract_can_signal(signal, payload):
 
     bit_count = signal.size
 
+    if start_bit + bit_count > vals.shape[1] * 8:
+        raise MdfException(
+            f'Could not extract signal "{signal.name}" with start '
+            f"bit {signal.get_startbit()} and bit count {signal.size} "
+            f"from the payload with shape {vals.shape}"
+        )
+
     byte_size, r = divmod(bit_offset + bit_count, 8)
     if r:
         byte_size += 1
@@ -1314,38 +1372,52 @@ def extract_can_signal(signal, payload):
 
             vals = np.column_stack(
                 [
-                    np.zeros(len(vals), dtype=f'<({extra_bytes},)u1'),
-                    vals[:, start_byte:start_byte+byte_size],
+                    np.zeros(len(vals), dtype=f"<({extra_bytes},)u1"),
+                    vals[:, start_byte : start_byte + byte_size],
                 ]
             )
             try:
-                vals = vals.view(f'>u{std_size}').ravel()
+                vals = vals.view(f">u{std_size}").ravel()
             except:
-                vals = np.frombuffer(vals.tobytes(), dtype=f'>u{std_size}')
+                vals = np.frombuffer(vals.tobytes(), dtype=f">u{std_size}")
 
         else:
             vals = np.column_stack(
                 [
-                    vals[:, start_byte:start_byte+byte_size],
-                    np.zeros(len(vals), dtype=f'<({extra_bytes},)u1'),
+                    vals[:, start_byte : start_byte + byte_size],
+                    np.zeros(len(vals), dtype=f"<({extra_bytes},)u1"),
                 ]
             )
             try:
-                vals = vals.view(f'<u{std_size}').ravel()
+                vals = vals.view(f"<u{std_size}").ravel()
             except:
-                vals = np.frombuffer(vals.tobytes(), dtype=f'<u{std_size}')
+                vals = np.frombuffer(vals.tobytes(), dtype=f"<u{std_size}")
 
     else:
         if big_endian:
             try:
-                vals = vals[:, start_byte:start_byte + byte_size].view(f'>u{std_size}').ravel()
+                vals = (
+                    vals[:, start_byte : start_byte + byte_size]
+                    .view(f">u{std_size}")
+                    .ravel()
+                )
             except:
-                vals = np.frombuffer(vals[:, start_byte:start_byte + byte_size].tobytes(), dtype=f'>u{std_size}')
+                vals = np.frombuffer(
+                    vals[:, start_byte : start_byte + byte_size].tobytes(),
+                    dtype=f">u{std_size}",
+                )
         else:
             try:
-                vals = vals[:, start_byte:start_byte+byte_size].view(f'<u{std_size}').ravel()
+                vals = (
+                    vals[:, start_byte : start_byte + byte_size]
+                    .view(f"<u{std_size}")
+                    .ravel()
+                )
             except:
-                vals = np.frombuffer(vals[:, start_byte:start_byte + byte_size].tobytes(), dtype=f'<u{std_size}')
+                vals = np.frombuffer(
+                    vals[:, start_byte : start_byte + byte_size].tobytes(),
+                    dtype=f"<u{std_size}",
+                )
 
     vals = vals >> bit_offset
     vals &= (2 ** bit_count) - 1
@@ -1389,17 +1461,20 @@ def extract_mux(payload, message, message_id, bus, t, muxer=None, muxer_values=N
     """
     extracted_signals = {}
 
+    if message.size > payload.shape[1]:
+        return extracted_signals
+
     # first go through the non-mutiplexers signals
     # create lists of signals that are not mutiplexed or they ahve the same
     # mutiplexor and the same lower and upper mutiplexing values
     pairs = {}
     for signal in message:
-        if signal.multiplex == 'Multiplexor' or signal.muxer_for_signal != muxer:
+        if signal.multiplex == "Multiplexor" or signal.muxer_for_signal != muxer:
             continue
         try:
             entry = signal.mux_val_min, signal.mux_val_max
         except:
-            entry = tuple(signal.mux_val_grp[0]) if signal.mux_val_grp else (0,0)
+            entry = tuple(signal.mux_val_grp[0]) if signal.mux_val_grp else (0, 0)
         if entry not in pairs:
             pairs[entry] = []
         pairs[entry].append(signal)
@@ -1413,15 +1488,20 @@ def extract_mux(payload, message, message_id, bus, t, muxer=None, muxer_values=N
 
             for sig in pair_signals:
                 samples = extract_can_signal(sig, payload)
-                max_val = float(sig.calc_max())
+                if len(samples) == 0 and len(t):
+                    continue
+
+                max_val = np.full(len(samples), float(sig.calc_max()))
+
                 signals[sig.name] = {
-                    'name': sig.name,
-                    'comment': sig.comment or "",
-                    'unit': sig.unit or "",
-                    'samples': samples,
-                    't': t,
-                    'is_max': np.all(samples == max_val),
+                    "name": sig.name,
+                    "comment": sig.comment or "",
+                    "unit": sig.unit or "",
+                    "samples": samples,
+                    "t": t,
+                    "invalidation_bits": np.isclose(samples, max_val),
                 }
+
         else:
             # select only the CAN messages where the multiplexor value is
             # within the range
@@ -1434,14 +1514,15 @@ def extract_mux(payload, message, message_id, bus, t, muxer=None, muxer_values=N
 
             for sig in pair_signals:
                 samples = extract_can_signal(sig, payload_)
-                max_val = float(sig.calc_max())
+                max_val = np.full(len(samples), float(sig.calc_max()))
+
                 signals[sig.name] = {
-                    'name': sig.name,
-                    'comment': sig.comment or "",
-                    'unit': sig.unit or "",
-                    'samples': samples,
-                    't': t_,
-                    'is_max': np.all(samples == max_val),
+                    "name": sig.name,
+                    "comment": sig.comment or "",
+                    "unit": sig.unit or "",
+                    "samples": samples,
+                    "t": t_,
+                    "invalidation_bits": np.isclose(samples, max_val),
                 }
 
     # then handle mutiplexers signals
@@ -1450,13 +1531,13 @@ def extract_mux(payload, message, message_id, bus, t, muxer=None, muxer_values=N
     # and the same lower and upper mutiplexing values
     pairs = {}
     for signal in message:
-        if signal.multiplex != 'Multiplexor' or signal.muxer_for_signal != muxer:
+        if signal.multiplex != "Multiplexor" or signal.muxer_for_signal != muxer:
             continue
 
         try:
             entry = signal.mux_val_min, signal.mux_val_max
         except:
-            entry = tuple(signal.mux_val_grp[0]) if signal.mux_val_grp else (0,0)
+            entry = tuple(signal.mux_val_grp[0]) if signal.mux_val_grp else (0, 0)
         if entry not in pairs:
             pairs[entry] = []
         pairs[entry].append(signal)
@@ -1472,15 +1553,17 @@ def extract_mux(payload, message, message_id, bus, t, muxer=None, muxer_values=N
                 signals = extracted_signals[entry]
 
             for sig in pair_signals:
-                max_val = float(sig.calc_max())
+
                 muxer_values = extract_can_signal(sig, payload)
+                max_val = np.full(len(muxer_values), float(sig.calc_max()))
+
                 signals[sig.name] = {
-                    'name': sig.name,
-                    'comment': sig.comment or "",
-                    'unit': sig.unit or "",
-                    'samples': muxer_values,
-                    't': t,
-                    'is_max': np.all(muxer_values == max_val),
+                    "name": sig.name,
+                    "comment": sig.comment or "",
+                    "unit": sig.unit or "",
+                    "samples": muxer_values,
+                    "t": t,
+                    "invalidation_bits": np.isclose(muxer_values, max_val),
                 }
 
                 # feed the muxer values to the mutliplexed signals
@@ -1510,15 +1593,16 @@ def extract_mux(payload, message, message_id, bus, t, muxer=None, muxer_values=N
                 signals = extracted_signals[entry]
 
             for sig in pair_signals:
-                max_val = float(sig.calc_max())
                 muxer_values_ = extract_can_signal(sig, payload_)
+                max_val = np.full(len(muxer_values_), float(sig.calc_max()))
+
                 signals[sig.name] = {
-                    'name': sig.name,
-                    'comment': sig.comment or "",
-                    'unit': sig.unit or "",
-                    'samples': muxer_values_,
-                    't': t_,
-                    'is_max': np.all(muxer_values == max_val),
+                    "name": sig.name,
+                    "comment": sig.comment or "",
+                    "unit": sig.unit or "",
+                    "samples": muxer_values_,
+                    "t": t_,
+                    "invalidation_bits": np.isclose(muxer_values_, max_val),
                 }
 
                 extracted_signals.update(
@@ -1543,7 +1627,8 @@ def csv_int2hex(val):
 
     """
 
-    return f'{val:X}'
+    return f"{val:X}"
+
 
 csv_int2hex = np.vectorize(csv_int2hex, otypes=[str])
 
@@ -1556,12 +1641,10 @@ def csv_bytearray2hex(val):
     """
     val = val.tobytes().hex().upper()
 
-    vals = [
-        val[i: i + 2]
-        for i in range(0, len(val), 2)
-    ]
+    vals = [val[i : i + 2] for i in range(0, len(val), 2)]
+
+    return " ".join(vals)
 
-    return ' '.join(vals)
 
 csv_bytearray2hex = np.vectorize(csv_bytearray2hex, otypes=[str])
 
@@ -1569,14 +1652,14 @@ csv_bytearray2hex = np.vectorize(csv_bytearray2hex, otypes=[str])
 def pandas_query_compatible(name):
     """ adjust column name for usage in dataframe query string """
 
-    for c in '.$[] ':
-        name = name.replace(c, '_')
+    for c in ".$[] ":
+        name = name.replace(c, "_")
     try:
-        exec(f'from pandas import {name}')
+        exec(f"from pandas import {name}")
     except ImportError:
         pass
     else:
-        name = f'{name}__'
+        name = f"{name}__"
     return name
 
 
@@ -1586,27 +1669,21 @@ def load_can_database(file, contents=None):
 
     dbc = None
 
-    if file.suffix.lower() in ('.dbc', '.arxml'):
+    if file.suffix.lower() in (".dbc", ".arxml"):
         if contents is None and file.exists():
             contents = file.read_bytes()
 
         if contents:
-            import_type = file.suffix.lower().strip('.')
-            loads = dbc_load if import_type == 'dbc' else arxml_load
+            import_type = file.suffix.lower().strip(".")
+            loads = dbc_load if import_type == "dbc" else arxml_load
 
             contents = BytesIO(contents)
             try:
                 try:
-                    dbc = loads(
-                        contents,
-                        import_type=import_type,
-                        key="db",
-                    )
+                    dbc = loads(contents, import_type=import_type, key="db",)
                 except UnicodeDecodeError:
                     encoding = detect(contents)["encoding"]
-                    contents = contents.decode(
-                        encoding
-                    )
+                    contents = contents.decode(encoding)
                     dbc = loads(
                         contents,
                         importType=import_type,
@@ -1625,3 +1702,20 @@ def load_can_database(file, contents=None):
             dbc = None
 
     return dbc
+
+
+def all_blocks_addresses(obj):
+    pattern = re.compile(
+        rb'(?P<block>##(D[GVTZIL]|AT|C[AGHNC]|EV|FH|HL|LD|MD|R[DVI]|S[IRD]|TX))',
+        re.DOTALL | re.MULTILINE,
+    )
+
+    try:
+        obj.seek(0)
+    except:
+        pass
+
+    return [
+         match.start()
+         for match in re.finditer(pattern, obj)
+    ]
