@@ -3,7 +3,7 @@
 from PyQt5 import QtGui
 from PyQt5 import QtWidgets
 from PyQt5 import QtCore
-from struct import pack, unpack
+from struct import pack
 import json
 
 from ..utils import extract_mime_names
@@ -12,6 +12,7 @@ from ..utils import extract_mime_names
 class ListWidget(QtWidgets.QListWidget):
 
     itemsDeleted = QtCore.pyqtSignal(list)
+    set_time_offset = QtCore.pyqtSignal(list)
     items_rearranged = QtCore.pyqtSignal()
     add_channels_request = QtCore.pyqtSignal(list)
 
@@ -33,6 +34,7 @@ class ListWidget(QtWidgets.QListWidget):
     def keyPressEvent(self, event):
         key = event.key()
         modifiers = event.modifiers()
+
         if key == QtCore.Qt.Key_Delete and self.can_delete_items:
             selected_items = self.selectedItems()
             deleted = []
@@ -48,8 +50,7 @@ class ListWidget(QtWidgets.QListWidget):
                 return
 
             states = [
-                self.itemWidget(item).display.checkState()
-                for item in selected_items
+                self.itemWidget(item).display.checkState() for item in selected_items
             ]
 
             if any(state == QtCore.Qt.Unchecked for state in states):
@@ -84,14 +85,17 @@ class ListWidget(QtWidgets.QListWidget):
                 return
             self.itemWidget(selected_items[0]).keyPressEvent(event)
 
-        elif modifiers == (QtCore.Qt.ControlModifier | QtCore.Qt.ShiftModifier ) and key in (QtCore.Qt.Key_C, QtCore.Qt.Key_P):
+        elif modifiers == (
+            QtCore.Qt.ControlModifier | QtCore.Qt.ShiftModifier
+        ) and key in (QtCore.Qt.Key_C, QtCore.Qt.Key_P):
             selected_items = self.selectedItems()
             if not selected_items:
                 return
             self.itemWidget(selected_items[0]).keyPressEvent(event)
 
         else:
-            super().keyPressEvent(event)
+            self.parent().keyPressEvent(event)
+            event.ignore()
 
     def startDrag(self, supportedActions):
         selected_items = self.selectedItems()
@@ -102,26 +106,30 @@ class ListWidget(QtWidgets.QListWidget):
 
         for item in selected_items:
 
-            name = item.name.encode('utf-8')
             entry = item.entry
             computation = item.computation
 
+            widget = self.itemWidget(item)
+
+            color = widget.color
+            unit = widget.unit
+
             if entry == (-1, -1):
                 info = {
-                    "name": name,
+                    "name": item.name,
                     "computation": computation,
+                    "computed": True,
+                    "unit": unit,
+                    "color": color,
                 }
-                info = json.dumps(info).encode('utf-8')
+                info = json.dumps(info).encode("utf-8")
             else:
-                info = name
+                info = item.name.encode("utf-8")
 
-            data.append(pack(f'<3Q{len(info)}s', entry[0], entry[1], len(info), info))
+            data.append(pack(f"<3q{len(info)}s", entry[0], entry[1], len(info), info))
 
         mimeData.setData(
-            'application/octet-stream-asammdf',
-            QtCore.QByteArray(
-                b''.join(data)
-            )
+            "application/octet-stream-asammdf", QtCore.QByteArray(b"".join(data))
         )
 
         drag = QtGui.QDrag(self)
@@ -129,7 +137,7 @@ class ListWidget(QtWidgets.QListWidget):
         drag.exec(QtCore.Qt.CopyAction)
 
     def dragEnterEvent(self, e):
-        if e.mimeData().hasFormat('application/octet-stream-asammdf'):
+        if e.mimeData().hasFormat("application/octet-stream-asammdf"):
             e.accept()
         super().dragEnterEvent(e)
 
@@ -139,7 +147,7 @@ class ListWidget(QtWidgets.QListWidget):
             self.items_rearranged.emit()
         else:
             data = e.mimeData()
-            if data.hasFormat('application/octet-stream-asammdf'):
+            if data.hasFormat("application/octet-stream-asammdf"):
                 names = extract_mime_names(data)
                 self.add_channels_request.emit(names)
             else:
@@ -166,6 +174,9 @@ class ListWidget(QtWidgets.QListWidget):
         menu.addAction(self.tr("Set unit"))
         menu.addAction(self.tr("Set precision"))
         menu.addSeparator()
+        menu.addAction(self.tr("Relative time base shift"))
+        menu.addAction(self.tr("Set time base start offset"))
+        menu.addSeparator()
         menu.addAction(self.tr("Delete (Del)"))
 
         action = menu.exec_(self.viewport().mapToGlobal(position))
@@ -175,9 +186,7 @@ class ListWidget(QtWidgets.QListWidget):
 
         if action.text() == "Copy name (Ctrl+C)":
             event = QtGui.QKeyEvent(
-                QtCore.QEvent.KeyPress,
-                QtCore.Qt.Key_C,
-                QtCore.Qt.ControlModifier,
+                QtCore.QEvent.KeyPress, QtCore.Qt.Key_C, QtCore.Qt.ControlModifier,
             )
             self.itemWidget(item).keyPressEvent(event)
 
@@ -197,7 +206,7 @@ class ListWidget(QtWidgets.QListWidget):
             )
             self.itemWidget(item).keyPressEvent(event)
 
-        if action.text() == "Enable all":
+        elif action.text() == "Enable all":
             for i in range(self.count()):
                 item = self.item(i)
                 widget = self.itemWidget(item)
@@ -238,11 +247,7 @@ class ListWidget(QtWidgets.QListWidget):
         elif action.text() == "Set unit":
             selected_items = self.selectedItems()
 
-            unit, ok = QtWidgets.QInputDialog.getText(
-                None,
-                'Set new unit',
-                'Unit:',
-            )
+            unit, ok = QtWidgets.QInputDialog.getText(None, "Set new unit", "Unit:",)
 
             if ok:
 
@@ -258,9 +263,7 @@ class ListWidget(QtWidgets.QListWidget):
             selected_items = self.selectedItems()
 
             precision, ok = QtWidgets.QInputDialog.getInt(
-                None,
-                'Set new precision (float decimals)',
-                'Precision:',
+                None, "Set new precision (float decimals)", "Precision:",
             )
 
             if ok and 0 <= precision <= 15:
@@ -272,17 +275,42 @@ class ListWidget(QtWidgets.QListWidget):
                         widget.set_precision(precision)
                         widget.update()
 
+        elif action.text() in ("Relative time base shift", "Set time base start offset"):
+            selected_items = self.selectedItems()
+            if selected_items:
+
+                if action.text() == "Relative time base shift":
+                    offset, ok = QtWidgets.QInputDialog.getDouble(
+                        self, "Relative offset [s]", "Offset [s]:",
+                    )
+                    absolute = False
+                else:
+                    offset, ok = QtWidgets.QInputDialog.getDouble(
+                        self, "Absolute time start offset [s]", "Offset [s]:",
+                    )
+                    absolute = True
+                if ok:
+                    uuids = []
+
+                    for i in range(self.count()):
+                        item = self.item(i)
+                        widget = self.itemWidget(item)
+                        if item in selected_items:
+
+                            uuids.append(widget.uuid)
+                    self.set_time_offset.emit([absolute, offset, ] + uuids)
+
         elif action.text() == "Delete (Del)":
             event = QtGui.QKeyEvent(
-                QtCore.QEvent.KeyPress,
-                QtCore.Qt.Key_Delete,
-                QtCore.Qt.NoModifier,
+                QtCore.QEvent.KeyPress, QtCore.Qt.Key_Delete, QtCore.Qt.NoModifier,
             )
             self.keyPressEvent(event)
 
 
 class MinimalListWidget(QtWidgets.QListWidget):
 
+    itemsDeleted = QtCore.pyqtSignal(list)
+
     def __init__(self, *args, **kwargs):
 
         super().__init__(*args, **kwargs)
@@ -292,6 +320,9 @@ class MinimalListWidget(QtWidgets.QListWidget):
 
         self.setAlternatingRowColors(True)
 
+        self.setContextMenuPolicy(QtCore.Qt.CustomContextMenu)
+        self.customContextMenuRequested.connect(self.open_menu)
+
         self.setAcceptDrops(True)
         self.show()
 
@@ -304,5 +335,27 @@ class MinimalListWidget(QtWidgets.QListWidget):
                 row = self.row(item)
                 deleted.append(row)
                 self.takeItem(row)
+            if deleted:
+                self.itemsDeleted.emit(deleted)
         else:
             super().keyPressEvent(event)
+
+    def open_menu(self, position):
+
+        item = self.itemAt(position)
+        if item is None:
+            return
+
+        menu = QtWidgets.QMenu()
+        menu.addAction(self.tr("Delete (Del)"))
+
+        action = menu.exec_(self.viewport().mapToGlobal(position))
+
+        if action is None:
+            return
+
+        if action.text() == "Delete (Del)":
+            event = QtGui.QKeyEvent(
+                QtCore.QEvent.KeyPress, QtCore.Qt.Key_Delete, QtCore.Qt.NoModifier,
+            )
+            self.keyPressEvent(event)
