@@ -80,7 +80,7 @@ class Signal(object):
         encoding=None,
     ):
 
-        if samples is None or timestamps is None or name == "":
+        if samples is None or timestamps is None or not name:
             message = (
                 '"samples", "timestamps" and "name" are mandatory '
                 "for Signal class __init__: samples={samples}\n"
@@ -88,15 +88,16 @@ class Signal(object):
             )
             raise MdfException(message)
         else:
-            if isinstance(samples, (list, tuple)):
+            if not isinstance(samples, np.ndarray):
                 samples = np.array(samples)
-            if isinstance(timestamps, (list, tuple)):
+            if not isinstance(timestamps, np.ndarray):
                 timestamps = np.array(timestamps, dtype=np.float64)
             if samples.shape[0] != timestamps.shape[0]:
                 message = "{} samples and timestamps length mismatch ({} vs {})"
                 message = message.format(name, samples.shape[0], timestamps.shape[0])
                 logger.exception(message)
                 raise MdfException(message)
+
             self.samples = samples
             self.timestamps = timestamps
             self.unit = unit
@@ -112,12 +113,9 @@ class Signal(object):
             self.channel_index = -1
 
             if source:
-                if isinstance(source, SignalSource):
-                    self.source = source
-                else:
-                    self.source = source.to_common_source()
-            else:
-                self.source = source
+                if not isinstance(source, SignalSource):
+                    source = source.to_common_source()
+            self.source = source
 
             if bit_count is None:
                 self.bit_count = samples.dtype.itemsize * 8
@@ -125,12 +123,24 @@ class Signal(object):
                 self.bit_count = bit_count
 
             self.stream_sync = stream_sync
+
+            if invalidation_bits is not None:
+                if not isinstance(
+                    invalidation_bits, np.ndarray
+                ):
+                    invalidation_bits = np.array(invalidation_bits)
+                if invalidation_bits.shape[0] != samples.shape[0]:
+                    message = "{} samples and invalidation bits length mismatch ({} vs {})"
+                    message = message.format(name, samples.shape[0], invalidation_bits.shape[0])
+                    logger.exception(message)
+                    raise MdfException(message)
             self.invalidation_bits = invalidation_bits
 
-            if not isinstance(
-                conversion, (v4b.ChannelConversion, v3b.ChannelConversion)
-            ):
-                conversion = from_dict(conversion)
+            if conversion:
+                if not isinstance(
+                    conversion, (v4b.ChannelConversion, v3b.ChannelConversion)
+                ):
+                    conversion = from_dict(conversion)
 
             self.conversion = conversion
 
@@ -149,13 +159,14 @@ class Signal(object):
 \tattachment={self.attachment}>
 """
 
-    def plot(self):
+    def plot(self, validate=True):
         """ plot Signal samples. Pyqtgraph is used if it is available; in this
         case see the GUI plot documentation to see the available commands"""
         try:
 
             from .gui.plot import plot
-            plot(self)
+
+            plot(self, validate=True)
             return
 
         except:
@@ -451,7 +462,9 @@ class Signal(object):
                         and ends[-1] not in self.timestamps
                         and ends[-1] < self.timestamps[-1]
                     ):
-                        interpolated = self.interp([ends[1]], interpolation_mode=interpolation_mode)
+                        interpolated = self.interp(
+                            [ends[1]], interpolation_mode=interpolation_mode
+                        )
                         samples = np.append(
                             self.samples[:stop], interpolated.samples, axis=0
                         )
@@ -515,7 +528,9 @@ class Signal(object):
                         and ends[0] not in self.timestamps
                         and ends[0] > self.timestamps[0]
                     ):
-                        interpolated = self.interp([ends[0]], interpolation_mode=interpolation_mode)
+                        interpolated = self.interp(
+                            [ends[0]], interpolation_mode=interpolation_mode
+                        )
                         samples = np.append(
                             interpolated.samples, self.samples[start:], axis=0
                         )
@@ -577,7 +592,9 @@ class Signal(object):
 
                     if start == stop:
                         if include_ends:
-                            interpolated = self.interp(np.unique(ends), interpolation_mode=interpolation_mode)
+                            interpolated = self.interp(
+                                np.unique(ends), interpolation_mode=interpolation_mode
+                            )
                             samples = interpolated.samples
                             timestamps = np.array(
                                 np.unique(ends), dtype=self.timestamps.dtype
@@ -605,7 +622,9 @@ class Signal(object):
                             and ends[-1] not in self.timestamps
                             and ends[-1] < self.timestamps[-1]
                         ):
-                            interpolated = self.interp([ends[1]], interpolation_mode=interpolation_mode)
+                            interpolated = self.interp(
+                                [ends[1]], interpolation_mode=interpolation_mode
+                            )
                             samples = np.append(samples, interpolated.samples, axis=0)
                             timestamps = np.append(timestamps, ends[1])
                             if invalidation_bits is not None:
@@ -618,7 +637,9 @@ class Signal(object):
                             and ends[0] not in self.timestamps
                             and ends[0] > self.timestamps[0]
                         ):
-                            interpolated = self.interp([ends[0]], interpolation_mode=interpolation_mode)
+                            interpolated = self.interp(
+                                [ends[0]], interpolation_mode=interpolation_mode
+                            )
                             samples = np.append(interpolated.samples, samples, axis=0)
                             timestamps = np.append(ends[0], timestamps)
 
@@ -729,8 +750,8 @@ class Signal(object):
         """
         if not len(self.samples) or not len(new_timestamps):
             return Signal(
-                self.samples.copy(),
-                self.timestamps.copy(),
+                self.samples[:0].copy(),
+                self.timestamps[:0].copy(),
                 self.unit,
                 self.name,
                 comment=self.comment,
@@ -740,9 +761,7 @@ class Signal(object):
                 display_name=self.display_name,
                 attachment=self.attachment,
                 stream_sync=self.stream_sync,
-                invalidation_bits=self.invalidation_bits.copy()
-                if self.invalidation_bits is not None
-                else None,
+                invalidation_bits=None,
                 encoding=self.encoding,
             )
         else:
@@ -1086,6 +1105,10 @@ class Signal(object):
             samples = self.samples.copy()
         else:
             samples = self.conversion.convert(self.samples)
+            if samples.dtype.kind == 'S':
+                encoding = 'utf-8' if self.conversion.id == b'##CC' else 'latin-1'
+            else:
+                encoding = None
 
         return Signal(
             samples,
@@ -1100,14 +1123,14 @@ class Signal(object):
             stream_sync=self.stream_sync,
             invalidation_bits=self.invalidation_bits,
             source=self.source,
-            encoding=self.encoding,
+            encoding=encoding,
         )
 
     def validate(self, copy=True):
         """ appply invalidation bits if they are available for this signal
 
-        Arguments
-        ---------
+        Parameters
+        ----------
         copy (True) : bool
             return a copy of the result
 
